
clear all
close all

addpath cuecombinationmodel\

load data\data_learmonth2002_GA

[ncond nloc] = size(D.data);

% Parameter range
noisevec = .001:.001:1;

minmse = Inf;

for i = 1:length(noisevec)
    
    noi = noisevec(i);
        
        cueparam = [noi]; Dfit = zeros(ncond,nloc);
        
        for c = 1:ncond
            [p] = posterior_L_given_model...
                (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(c),0,noi);
            Dfit(c,:) = p;
        end
        
        % MSE
        Dfit = Dfit * 100;
        E = mean(mean((D.data - Dfit).^2));
        
        % Update results
        if E < minmse FitOpt = Dfit; ParamOpt = cueparam; minmse = E; end
        
    i
end

% Geometry only
Dfit_g = Dfit;
for c = 1:ncond
    [gg] = posterior_L_given_model...
        ([1 0 0],D.cues{c},D.age(c),D.size(c),0,noi);
    Dfit_g(c,:) = gg;
end
Dfit_g = Dfit_g * 100;


% Geometry only
Dfit_a = Dfit;
for c = 1:ncond
    [aa] = posterior_L_given_model...
        ([0 1 0],D.cues{c},D.age(c),D.size(c),0,noi);
    Dfit_a(c,:) = aa;
end
Dfit_a = Dfit_a * 100;

% Plot

MillerFit = [    54 17 21 8
    68 15 16 1
    83 9 8 0
    49 27 18 6
    61 23 16 0
    75 18 7 0];

for k = 1:ncond
    
    subplot(2,ceil(ncond/2),k)
    bar([D.data(k,:)' FitOpt(k,:)' MillerFit(k,:)' Dfit_g(k,:)' Dfit_a(k,:)'])
    
    ylim([0 100]); xlim([0.5 nloc+.5])
    set(gca,'fontsize',12)
    set(gca,'XTick',[])
    box off
    colormap gray
    
    if k == 1 legend('Empirical','Combination','Miller''s','G-cue only','A-cue only');  legend boxoff; end
    if mod(k,ceil(ncond/2)) == 1 ylabel('Choice (%)','fontsize',15); end
    for j = 1:nloc text(j,-8,D.cornerlab{j},'fontsize',12); end
    
    clabs = '';
    for j = 1:size(D.cue_flags,2)
        if D.cue_flags(k,j) == 1
            clabs = [clabs,D.cuelab{j}];
        end
    end
    if D.size(k) == 24
        title(['Age ',num2str(D.age(k)),' (small)'],'fontsize',12)
    elseif D.size(k) == 96
        title(['Age ',num2str(D.age(k)),' (large)'],'fontsize',12)
    end
    
end

%save('params_optimal_learmonth2002_GA.mat','ParamOpt','noisevec')
ParamOpt
minmse

% Compare to MS fit
MS1 = [54 17 21 8
    68 15 16 1
    83 9 8 0];
MS2 = [49 27 18 6
    61 23 16 0
    75 18 7 0];

D1 = D.data(1:3,:); Mine1 = FitOpt(1:3,:);
D2 = D.data(4:6,:); Mine2 = FitOpt(4:6,:);

corrMine1 = (corr(reshape(D1, prod(size(D1)), 1), reshape(Mine1, prod(size(D1)), 1)));
corrMS1 = (corr(reshape(D1, prod(size(D1)), 1), reshape(MS1, prod(size(D1)), 1)));
corrMine2 = (corr(reshape(D2, prod(size(D2)), 1), reshape(Mine2, prod(size(D2)), 1)));
corrMS2 = (corr(reshape(D2, prod(size(D2)), 1), reshape(MS2, prod(size(D2)), 1)));

r2Mine1 = corrMine1^2
r2MS1 = corrMS1^2
r2Geo1 = corr(reshape(D1, prod(size(D1)), 1), reshape(Dfit_g(1:3,:), prod(size(D1)), 1))^2;
r2Mine2 = corrMine2^2
r2MS2 = corrMS2^2
r2Geo2 = corr(reshape(D2, prod(size(D1)), 1), reshape(Dfit_g(4:6,:), prod(size(D1)), 1))^2;
r2Dir1 = corr(reshape(D1, prod(size(D1)), 1), reshape(Dfit_a(1:3,:), prod(size(D1)), 1))^2;
r2Dir2 = corr(reshape(D2, prod(size(D1)), 1), reshape(Dfit_a(4:6,:), prod(size(D1)), 1))^2;

disp(['r2Mine1: ',num2str(r2Mine1),'   ','r2MS1: ',num2str(r2MS1),'   ','r2Geo1: ',num2str(r2Geo1),'   ','r2Dir1: ',num2str(r2Dir1)])
disp(['r2Mine2: ',num2str(r2Mine2),'   ','r2MS2: ',num2str(r2MS2),'   ','r2Geo2: ',num2str(r2Geo2),'   ','r2Dir2: ',num2str(r2Dir2)])



aic_mine1 = computeLIKE(reshape(D1, prod(size(D1)), 1), reshape(Mine1, prod(size(D1)),1),3,1)
aic_MS1 = computeLIKE(reshape(D1, prod(size(D1)), 1), reshape(MS1, prod(size(D1)),1),3,4) % 3 unique alphas and 1 beta
aic_Geo1 = computeLIKE(reshape(D1, prod(size(D1)), 1), reshape(Dfit_g(1:3,:), prod(size(D1)), 1),3,1)
aic_Dir1 = computeLIKE(reshape(D1, prod(size(D1)), 1), reshape(Dfit_a(1:3,:), prod(size(D1)), 1),3,1)

aic_mine2 = computeLIKE(reshape(D2, prod(size(D2)), 1), reshape(Mine2, prod(size(D2)),1),3,1)
aic_MS2 = computeLIKE(reshape(D2, prod(size(D2)), 1), reshape(MS2, prod(size(D2)),1),3,4) % 3 unique alphas and 1 beta
aic_Geo2 = computeLIKE(reshape(D2, prod(size(D2)), 1), reshape(Dfit_g(4:6,:), prod(size(D2)), 1),3,1)
aic_Dir2 = computeLIKE(reshape(D2, prod(size(D2)), 1), reshape(Dfit_a(4:6,:), prod(size(D2)), 1),3,1)

