
clear all
close all

addpath cuecombinationmodel\
addpath results\

load data\data_newcombe2009_GP

[ncond nloc] = size(D.data);

% Optimal parameters fitted from 'analysis_fit_learmonth2002.m'
load params_optimal_learmonth2002_GA
noi = ParamOpt;

Dpred = zeros(ncond,nloc);

Mpred = [];
for c = 1:ncond
    % GP
    [p] = posterior_L_given_model...
        (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(c),0,noi);
    Dpred(c,:) = p;
    if c == 1 % Simulated miller prediction
        Mpred = [33.7336    5.9425   10.2117    4.4019   11.6255    5.7803   11.5267   16.7779];
    else
        Mpred = [Mpred; 55.1441         0    7.4036         0   10.0506         0    9.8981   17.5036];
    end
    % G only
    [gg] = posterior_L_given_model...
        ([1 0 0],D.cues{c},D.age(c),D.size(c),0,noi);
    Dpred_g(c,:) = gg;
    % P only
    [pp] = posterior_L_given_model...
        ([0 0 1],D.cues{c},D.age(c),D.size(c),0,noi);
    Dpred_p(c,:) = pp;
end

Dpred = Dpred * 100;
Dpred_g = Dpred_g * 100;
Dpred_p = Dpred_p * 100;

for k = 1:ncond
    
    subplot(2,ncond,k)
    bar([D.data(k,:)' Dpred(k,:)' Mpred(k,:)' Dpred_g(k,:)' Dpred_p(k,:)' ])
    
    hold on
    for ii = 1:size(D.data_se,2)
        ll=line([ii-.3,ii-.3],[2*D.data_se(k,ii)+D.data(k,ii),D.data(k,ii)-2*D.data_se(k,ii)]);
        set(ll,'color','k')
    end
    
    
    ylim([0 60]); xlim([0.5 nloc+.5])
    set(gca,'fontsize',12)
    set(gca,'XTick',[])
    box off
    colormap gray
    
    if k == 1 
        legend('Empirical','Combination','Miller''s','G-cue only','P-cue only');  legend boxoff; 
        ylabel('Choice (%)','fontsize',15)
    end
    if mod(k,ceil(ncond/2)) == 1 ylabel('Choice (%)','fontsize',15); end
    for j = 1:nloc text(j-.15,-8,D.cornerlab{j},'fontsize',12); end
    
    clabs = '';
    for j = 1:size(D.cue_flags,2)
        if D.cue_flags(k,j) == 1
            clabs = [clabs,D.cuelab{j}];
        end
    end
    
    title(['Age ',num2str(floor(D.age(k))),''],'fontsize',12)
    
end


corrDpred = (corr(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred, prod(size(D.data)), 1)));
corrDpred_g = (corr(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred_g, prod(size(D.data)), 1)));
corrDpred_p = (corr(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred_p, prod(size(D.data)), 1)));
corrM = (corr(reshape(D.data, prod(size(D.data)), 1), reshape(Mpred, prod(size(D.data)), 1)));

r2Dpred = corrDpred^2
r2Dpred_g = corrDpred_g^2
r2Dpred_p = corrDpred_p^2
r2Miller = corrM^2

aic_mine = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred, prod(size(D.data)),1),2,1)
aic_g = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred_g, prod(size(D.data)), 1),2,1)
aic_p = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Dpred_p, prod(size(D.data)), 1),2,1)
aic_MS = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Mpred, prod(size(D.data)), 1),2,4) % 3 alphas and 1 beta