% p(t|c) = p(c|t) p(t|c-)
% Posterior updating

clear all
close all

addpath cuecombinationmodel\
addpath results\

load data\data_ratliff2008_GA_conflict

noifactor = 1./(1:10); nlevel = length(noifactor);
[ncond nloc] = size(D.data);

% Optimal parameters fitted from 'analysis_fit_learmonth2002.m'
load params_optimal_learmonth2002_GA
noi = ParamOpt;

h=0;

Dfit = zeros(ncond,nloc);
DfitG = Dfit; DfitA = Dfit; DfitL = Dfit; DfitNoPrior = Dfit;
DfitANoPrior = Dfit; DfitGNoPrior = Dfit;

% Average across different levels of noise
for c = 1:2
    
    for n = 1:nlevel
        
        noival = noi * noifactor(n);
        
        % Get prior from training
        [prior_vec] = posterior_L_given_model...
            (D.cue_flags(c,:),D.cues_train{c},D.age(c),D.size(1,c),0,noival);
        
        % Predict posterior in testing
        p = posterior_L_given_model...
            (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(2,c),h,noival,prior_vec);
        
        pnoprior = posterior_L_given_model...
            (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(2,c),h,noival);
        
        Dfit(c,:) = Dfit(c,:)+p;  DfitNoPrior(c,:) = DfitNoPrior(c,:)+pnoprior;
        
        % Competitor models
        cueinds = find(D.cue_flags(c,:)==1);
        for i = 1:length(cueinds)
            qflag = zeros(1,4); qflag(cueinds(i)) = 1; q = D.cues_train{c}(cueinds(i),:);
            [priors] = posterior_L_given_model(qflag,q,D.age(c),D.size(1,c),h,noival);
            [posteriors] = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noival,priors);
            if cueinds(i) == 1
                DfitG(c,:) = DfitG(c,:)+posteriors;
                postnoprior = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noival);
                DfitGNoPrior(c,:) = DfitGNoPrior(c,:)+postnoprior;
            elseif cueinds(i) == 2
                DfitA(c,:) = DfitA(c,:)+posteriors;
                postnoprior = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noival);
                DfitANoPrior(c,:) = DfitANoPrior(c,:)+postnoprior;
            else
                DfitL(c,:) = DfitL(c,:)+posteriors;
            end
        end
        
    end
    
    % Average across noise levels
    Dfit(c,:) = Dfit(c,:) / nlevel;
    DfitNoPrior(c,:) = DfitNoPrior(c,:) / nlevel;
    DfitG(c,:) = DfitG(c,:) / nlevel;
    DfitGNoPrior(c,:) = DfitGNoPrior(c,:) / nlevel;
    DfitA(c,:) = DfitA(c,:) / nlevel;
    DfitANoPrior(c,:) = DfitANoPrior(c,:) / nlevel;
    DfitL(c,:) = DfitL(c,:) / nlevel;
    
    c
end

for c = 3:4
    
    % Get prior from training
    [prior_vec] = posterior_L_given_model...
        (D.cue_flags(c,:),D.cues_train{c},D.age(c),D.size(1,c),0,noi);
    
    % Predict posterior in testing
    p = posterior_L_given_model...
        (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(2,c),h,noi,prior_vec);
    
    pnoprior = posterior_L_given_model...
        (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(2,c),h,noi);
    
    Dfit(c,:) = p;  DfitNoPrior(c,:) = pnoprior;
    
    % Competitor models
    cueinds = find(D.cue_flags(c,:)==1);
    for i = 1:length(cueinds)
        qflag = zeros(1,4); qflag(cueinds(i)) = 1; q = D.cues_train{c}(cueinds(i),:);
        [priors] = posterior_L_given_model(qflag,q,D.age(c),D.size(1,c),h,noi);
        [posteriors] = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noi,priors);
        if cueinds(i) == 1
            DfitG(c,:) = posteriors;
            postnoprior = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noi);
            DfitGNoPrior(c,:) = postnoprior;
        elseif cueinds(i) == 2
            DfitA(c,:) = posteriors;
            postnoprior = posterior_L_given_model(qflag,q,D.age(c),D.size(2,c),h,noi);
            DfitANoPrior(c,:) = postnoprior;
        else
            DfitL(c,:) = posteriors;
        end
    end
    
end

% MSE
Dfit = Dfit * 100; DfitG = DfitG * 100; DfitA = DfitA * 100; DfitL = DfitL * 100;
DfitNoPrior = DfitNoPrior * 100;

condinds = [1 2 3 4];

for i = 1:ncond
    
    k = condinds(i);
    
    subplot(2,ceil(ncond/2),i)
    %bar([D.data(k,:)'  Dfit(k,:)' DfitNoPrior(k,:)'])
    bar([D.data(k,:)'  Dfit(k,:)'  DfitG(k,:)' DfitA(k,:)' ])
    for ii = 1:size(D.data_se,2)
        ll = line([ii-.27,ii-.27],[D.data(k,ii)-D.data_se(k,ii)*2,D.data(k,ii)+D.data_se(k,ii)*2]);
        set(ll,'color','k')
    end
    %{
    hold on
    xoffset = -.27;
    for ll = 1:size(D.data_se,2)
        line([ll+xoffset ll+xoffset],...
            [D.data(k,ll)+D.data_se(k,ll)*2 ...
            D.data(k,ll)-D.data_se(k,ll)*2]);
    end
    %}
    
    ylim([0 100]); xlim([0.5 nloc+.5])
    set(gca,'fontsize',12)
    set(gca,'XTick',[])
    box off
    colormap gray
    
    if i == 1 legend('Empirical','Combination','G-cue only','A-cue only');  legend boxoff; end
    if mod(i,ceil(ncond/2)) == 1 ylabel('Choice (%)','fontsize',15); end
    for j = 1:nloc text(j,-8,D.cornerlab{j},'fontsize',12); end
    
    if k == 1 title('Large \Rightarrow Large')
    elseif k == 2 title('Small \Rightarrow Small')
    elseif k == 3 title('Small \Rightarrow Large')
    else title('Large \Rightarrow Small'); end
    
    clabs = '';
    for j = 1:size(D.cue_flags,2)
        if D.cue_flags(k,j) == 1
            clabs = [clabs,D.cuelab{j}];
        end
    end
    
    
end

corrDfit = corr(reshape(D.data, prod(size(D.data)), 1), reshape(Dfit, prod(size(D.data)), 1));
r2Dfit = corrDfit^2
r2DfitA = corr(reshape(D.data, prod(size(D.data)), 1), reshape(DfitA, prod(size(D.data)), 1))^2
r2DfitG = corr(reshape(D.data, prod(size(D.data)), 1), reshape(DfitG, prod(size(D.data)), 1))^2
r2DfitNoPrior = corr(reshape(D.data, prod(size(D.data)), 1), reshape(DfitNoPrior, prod(size(D.data)), 1))^2
%r2DfitNoAPrior = num2str(rsquare(reshape(D.data, prod(size(D.data)), 1), reshape(DfitANoPrior, prod(size(D.data)), 1)),2);
%r2DfitNoGPrior = num2str(rsquare(reshape(D.data, prod(size(D.data)), 1), reshape(DfitGNoPrior, prod(size(D.data)), 1)),2);

aic_mine1 = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Dfit, prod(size(D.data)), 1),4,1)
aic_A = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(DfitA, prod(size(D.data)), 1),4,1)
aic_G = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(DfitG, prod(size(D.data)), 1),4,1)
aic_NoPrior = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(DfitNoPrior, prod(size(D.data)), 1),4,1)
