
clear all
close all

addpath cuecombinationmodel\
addpath results\

load data\data_ratliff2008_GA_verbalshadow

[ncond nloc] = size(D.data);



% Optimal parameters fitted from 'analysis_fit_learmonth2002.m'
load params_optimal_learmonth2002_GA
noi = ParamOpt;

hvec = .1:.1:.9; % Integrate out the parameter within the entire range

DfitCell = cell(1,length(hvec));
DfitMean = 0;

for i = 1:length(hvec)
    
    h = hvec(i);
    
    Dfit = zeros(ncond,nloc);
    
    for c = 1:ncond
        [p] = posterior_L_given_model...
            (D.cue_flags(c,:),D.cues{c},D.age(c),D.size(c),D.shadow(c)*h,noi);
        %([0 1 0],D.cues{c},D.age(c),D.size(c),1,D.shadow(c)*h,v,alp,bet);
        
        Dfit(c,:) = p;
    end
    
    % MSE
    Dfit = Dfit * 100;
    
    DfitCell{i} = Dfit;
    DfitMean = Dfit + DfitMean;
    
end

DfitMean = DfitMean / length(hvec);

gpred_stack = [];
apred_stack = [];
mpred_stack = [];

figure % Put shadowed and non-shadowed back-to-back
for k = 1:10
    
    if k == 1 || k == 3
        if k == 1 subplot(2,5,1); else subplot(2,5,6); end
        bar([D.data(k,:)'  D.data(k+1,:)'])
        for ii = 1:size(D.data_se,2)
            ll = line([ii-.15,ii-.15],[D.data(k,ii)+D.data_se(k,ii)*2,D.data(k,ii)-D.data_se(k,ii)*2]);
            set(ll,'color','k')
            ll = line([ii+.15,ii+.15],[D.data(k+1,ii)+D.data_se(k+1,ii)*2,D.data(k+1,ii)-D.data_se(k+1,ii)*2]);
            set(ll,'color','k')
        end
        
    elseif k == 2 || k == 4
        if k == 2 subplot(2,5,2); else subplot(2,5,7); end
        bar([Dfit(k-1,:)'  Dfit(k,:)'])
    elseif k == 5 || k == 6
        if k == 5 subplot(2,5,3);
            % results from simulating Miller's model
            MS_simul_lg = [90.6435    5.1063    4.2502         0];
            cc = MS_simul_lg;
            bar([cc' cc'])
            
            mpred_stack = [mpred_stack; cc';cc'];
            
        else subplot(2,5,8);
            
            MS_simul_sm = [85.4256    9.2405    5.3339         0];
            cc = MS_simul_lg;
            bar([cc' cc'])
            
            mpred_stack = [mpred_stack; cc';cc'];
            
        end
        
    elseif k == 7 || k ==8
        if k == 7 subplot(2,5,4); else subplot(2,5,9); end
        gpred = [1 1 1/ParamOpt/D.age(1) 1/ParamOpt/D.age(1)];
        gpred = gpred/sum(gpred)*100;
        bar([gpred' gpred'])
        
        gpred_stack = [gpred_stack; gpred';gpred'];
        
    elseif k == 9 || k ==10
        if k == 9 subplot(2,5,5); else subplot(2,5,10); end
        dpred = [1 1/ParamOpt/D.age(1) 1 1/ParamOpt/D.age(1)];
        dpred = dpred/sum(dpred)*100;
        bar([dpred' dpred'])
        
        apred_stack = [apred_stack; dpred';dpred'];
        
    end
    
    ylim([0 105]); xlim([0.5 nloc+.5])
    set(gca,'fontsize',11)
    set(gca,'XTick',[])
    box off
    colormap gray
    
    if k == 1 legend('No shadow','Shadowed');  legend boxoff; end
    if k == 1 || k == 3 ylabel('Choice (%)','fontsize',15); end
    for j = 1:nloc text(j,-8,D.cornerlab{j},'fontsize',12); end
    
    clabs = '';
    %for j = 1:size(D.cue_flags,2)
    %if D.cue_flags(k,j) == 1
    %    clabs = [clabs,D.cuelab{j}];
    %end
    %end
    if k == 1
        title('Empirical (Large)')
    elseif k == 2
        title('Combination (Large)')
    elseif k == 3
        title('(Small)')
    elseif k == 4
        title('(Small)')
    elseif k == 5
        title('Miller''s (Large)')
    elseif k == 6
        title('(Small)')
    elseif k == 7
        title('G-cue only (Large)')
    elseif k == 8
        title('(Small)')
    elseif k == 9
        title('A-cue only (Large)')
    elseif k == 10
        title('(Small)')
    end
    
end


corrDfit = corr(reshape(D.data, prod(size(D.data)), 1), reshape(Dfit, prod(size(D.data)), 1));
r2Dfit = corrDfit^2
r2Dfit_miller =  (corr(reshape(D.data, prod(size(D.data)), 1), mpred_stack))^2
r2Dfit_geo =  (corr(reshape(D.data, prod(size(D.data)), 1), gpred_stack))^2
r2Dfit_a =  (corr(reshape(D.data, prod(size(D.data)), 1), apred_stack))^2



aic_mine = computeLIKE(reshape(D.data, prod(size(D.data)), 1), reshape(Dfit, prod(size(D.data)), 1),4,1)
aic_MS = computeLIKE(reshape(D.data, prod(size(D.data)), 1), mpred_stack,4,4)
aic_G = computeLIKE(reshape(D.data, prod(size(D.data)), 1), gpred_stack,4,1)
aic_A = computeLIKE(reshape(D.data, prod(size(D.data)), 1), apred_stack,4,1)
