function [p] = posterior_L_given_model(cue_flags,cues,age,z,h,noi,prior_vec,cue_prior)
% cue_flags - 1 x #cues as indicators of cue presence
% cues - #cues x #locations
% z - room size (inch squared)
% h - shadowing parameter [ 0 1 ]
% noi - noise parameter

if nargin < 7
    [ncue nloc] = size(cues);
    priorp = priorproduct(); prior_vec = priorp * ones(1,nloc);
end

cueinds = find(cue_flags>0); [ncue nloc] = size(cues);

like_vec = ones(1,nloc);
% Compute likelihood from each cue
if ncue > 1
    for i = 1:ncue
        if ~isempty(find(cueinds==i))
            cue = cues(i,:);
            if i == 1
                like_vec = like_vec.*likelihood_G(cue,age,noi);
            elseif i == 2
                like_vec = like_vec.*likelihood_A(cue,age,z,h,noi);
            elseif i == 3
                like_vec = like_vec.*likelihood_P(cue,age,noi);
            elseif i == 4
                like_vec = like_vec.*likelihood_L(cue,age,h,noi);
            end
        end
    end
else
    cue = cues;
    if cueinds == 1
        like_vec = like_vec.*likelihood_G(cue,age,noi);
    elseif cueinds == 2
        like_vec = like_vec.*likelihood_A(cue,age,z,h,noi);
    elseif cueinds == 3
        like_vec = like_vec.*likelihood_P(cue,age,noi);
    elseif cueinds == 4
        like_vec = like_vec.*likelihood_L(cue,age,h,noi);
    end
end

%{
if nargin > 7
    % p(t|c) ~ p(c|t) p(t) ~ prod_i f(t|c_i)p(c_i) p(t)
    cueinds = find(cue_flags==1);
    Likes = cues(cueinds,:); F_t_given_c = Likes;
    Priors = cue_prior;
    if length(Priors)~=size(Likes,1)
        disp('Error - prior and likelihood size mismatch');
    end
    for i = 1:length(cueinds)
        % Update likelihoods
        if cueinds(i) == 1
            like_v = likelihood_G(Likes(i,:),age,noi);
        elseif cueinds(i) == 2
            like_v = likelihood_A(Likes(i,:),age,z,h,noi);
        elseif cueinds(i) == 3
            like_v = likelihood_P(Likes(i,:),age,noi);
        elseif cueinds(i) == 4
            like_v = likelihood_L(Likes(i,:),age,h,noi);
        end
        F_t_given_c(i,:) = like_v;
    end
    % prod_i f(t|c_i)p(c_i)
    like_vec = F_t_given_c .* repmat(Priors',1,nloc);
    like_vec = like_vec ./ repmat(sum(like_vec,1),length(Priors),1);
    like_vec = prod(like_vec);
end
%}

p = like_vec .* prior_vec;
p = p / sum(p); % Normalization over all locations

end