function [p] = posterior_L_given_model_cuepriors(cue_flags,cues,age,z,h,noi,cuepriors)
% cue_flags - 1 x #cues as indicators of cue presence
% cues - #cues x #locations
% z - room size (inch squared)
% h - shadowing parameter [ 0 1 ]
% noi - noise parameter

cueinds = find(cue_flags>0); [ncue nloc] = size(cues);

like_vec = ones(1,nloc);
% Compute likelihood from each cue
if ncue > 1
    for i = 1:ncue
        if ~isempty(find(cueinds==i))
            cue = cues(i,:); cuepr = cuepriors(i,:);
            like_vec = like_vec.*likepriorupdate(cue,age,z,h,noi,...
                cuepriors(i,:),i);
        end
    end
else
    cue = cues;
    like_vec = like_vec.*likepriorupdate(cue,age,z,h,noi,cuepriors,cueinds);
end


p = like_vec;
p = p / sum(p); % Normalization over all locations

function [likeprior] = likepriorupdate(cue,age,z,h,noi,pr,i)

if i == 1
    lv = likelihood_G(cue,age,noi);
elseif i == 2
    lv = likelihood_A(cue,age,z,h,noi);
elseif i == 3
    lv = likelihood_P(cue,age,noi);
else
    lv = likelihood_L(cue,age,h,noi);
end

nloc = length(lv);

likeprior = (lv*pr(1)) ./ (lv*pr(1) + pr(2)/nloc*ones(1,nloc));